@@ -832,6 +832,40 @@ func TestSourceStateApplyAll(t *testing.T) {
 	}
 }
 
+func TestSourceStateExecuteTemplateData(t *testing.T) {
+	for _, tc := range []struct {
+		name        string
+		dataStr     string
+		expectedStr string
+	}{
+		{
+			name: "line_ending_lf",
+			dataStr: "" +
+				"unix\n" +
+				"\n" +
+				"windows\r\n" +
+				"\r\n" +
+				"# chezmoi:template:line-ending=lf\n",
+			expectedStr: chezmoitest.JoinLines(
+				"unix",
+				"",
+				"windows",
+				"",
+			),
+		},
+	} {
+		t.Run(tc.name, func(t *testing.T) {
+			s := NewSourceState()
+			actual, err := s.ExecuteTemplateData(ExecuteTemplateDataOptions{
+				Name: tc.name,
+				Data: []byte(tc.dataStr),
+			})
+			assert.NoError(t, err)
+			assert.Equal(t, tc.expectedStr, string(actual))
+		})
+	}
+}
+
 func TestSourceStateRead(t *testing.T) {
 	for _, tc := range []struct {
 		name                string
@@ -1285,8 +1319,18 @@ func TestSourceStateRead(t *testing.T) {
 			},
 			expectedSourceState: NewSourceState(
 				withTemplates(
-					map[string]*template.Template{
-						"template": template.Must(template.New("template").Option("missingkey=error").Parse("# contents of .chezmoitemplates/template\n")),
+					map[string]*Template{
+						"template": {
+							name: "template",
+							template: template.Must(
+								template.New("template").
+									Option("missingkey=error").
+									Parse("# contents of .chezmoitemplates/template\n"),
+							),
+							options: TemplateOptions{
+								Options: []string{"missingkey=error"},
+							},
+						},
 					},
 				),
 			),
@@ -1759,10 +1803,24 @@ func TestTemplateOptionsParseDirectives(t *testing.T) {
 				Options: []string{"missingkey=zero"},
 			},
 		},
+		{
+			name:    "line_ending_crlf",
+			dataStr: "chezmoi:template:line-ending=crlf",
+			expected: TemplateOptions{
+				LineEnding: "\r\n",
+			},
+		},
+		{
+			name:    "line_ending_quoted",
+			dataStr: `chezmoi:template:line-ending="\n"`,
+			expected: TemplateOptions{
+				LineEnding: "\n",
+			},
+		},
 	} {
 		t.Run(tc.name, func(t *testing.T) {
 			var actual TemplateOptions
-			actualData := actual.parseDirectives([]byte(tc.dataStr))
+			actualData := actual.parseAndRemoveDirectives([]byte(tc.dataStr))
 			assert.Equal(t, tc.expected, actual)
 			assert.Equal(t, tc.expectedDataStr, string(actualData))
 		})
@@ -1837,7 +1895,7 @@ func withUserTemplateData(templateData map[string]any) SourceStateOption {
 	}
 }
 
-func withTemplates(templates map[string]*template.Template) SourceStateOption {
+func withTemplates(templates map[string]*Template) SourceStateOption {
 	return func(s *SourceState) {
 		s.templates = templates
 	}
