@@ -360,6 +360,8 @@ func newConfig(options ...configOption) (*Config, error) {
 		"glob":                     c.globTemplateFunc,
 		"gopass":                   c.gopassTemplateFunc,
 		"gopassRaw":                c.gopassRawTemplateFunc,
+		"hexDecode":                c.hexDecodeTemplateFunc,
+		"hexEncode":                c.hexEncodeTemplateFunc,
 		"include":                  c.includeTemplateFunc,
 		"includeTemplate":          c.includeTemplateTemplateFunc,
 		"ioreg":                    c.ioregTemplateFunc,
@@ -2053,6 +2055,12 @@ func (c *Config) readConfig() error {
 	}
 }
 
+// resetSourceState clears the cached source state, if any.
+func (c *Config) resetSourceState() {
+	c.sourceState = nil
+	c.sourceStateErr = nil
+}
+
 // run runs name with args in dir.
 func (c *Config) run(dir chezmoi.AbsPath, name string, args []string) error {
 	cmd := exec.Command(name, args...)
